@@ -1,4 +1,5 @@
 import abc
+import builtins
 import datetime
 import enum
 import typing
@@ -7,11 +8,10 @@ import jsii
 import jsii.compat
 import publication
 
-from jsii.python import classproperty
-
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_events
 import aws_cdk.aws_iam
+import aws_cdk.aws_kms
 import aws_cdk.core
 __all__ = []
 
